@@ -79,10 +79,14 @@ warnings.filterwarnings('ignore', category=UserWarning, append=True)
 # For numpy boolean arrays
 warnings.filterwarnings('ignore', category=FutureWarning, append=True)
 
-__version__ = '3.7.1'
+__version__ = '3.7.2'
 
 ap_dir = Path('/data/apogee/archive/')
+if not ap_dir.exists():
+    ap_dir = Path.home() / 'data/apogee/archive'
 b_dir = Path('/data/spectro/')
+if not b_dir.exists():
+    b_dir = Path.home() / 'data/spectro'
 
 
 class Logging:
@@ -113,7 +117,7 @@ class Logging:
 
     def __init__(self, ap_images, m_images, args):
         self.ap_images = ap_images
-        self.m_images = m_images
+        self.b_images = m_images
         self.args = args
         # Dictionary keys that begin with c are of len(carts_in_a_night),
         # keys that begin with i are of len(images_in_a_night), keys that begin
@@ -154,14 +158,9 @@ class Logging:
         # self.ap_tester = ap_test.ApogeeFlat(
         #     Path(__file__).absolute().parent.parent
         #     / 'dat/ap_master_flat_col_array.dat', self.args)
-        master_path = (Path(__file__).absolute().parent.parent
+        master_path = (Path(apogee_data.__file__).absolute().parent.parent
                        / 'dat/master_dome_flat_1.npy')
-        try:
-            master_data = np.load(master_path.as_posix())
-        except FileNotFoundError:
-            master_path = (Path(__file__).absolute().parent.parent.parent
-                           / 'dat/master_dome_flat_1.npy')
-            master_data = np.load(master_path.as_posix())
+        master_data = np.load(master_path.as_posix())
 
         self.ap_master = np.average(master_data[:, 900:910], axis=1)
 
@@ -219,7 +218,7 @@ class Logging:
         """Goes through every image in ap_images and m_images to put them in
         dictionaries."""
         if self.args.apogee:
-            print('Reading APOGEE Data')
+            print('Reading APOGEE Data ({})'.format(len(self.ap_images)))
             for image in tqdm(self.ap_images):
                 # print(image)
                 img = apogee_data.APOGEERaw(image, self.args, 1)
@@ -247,7 +246,7 @@ class Logging:
                               " type {}".format(img.file, img.exp_type))
                 elif ('Object' in img.exp_type) and ('-a-' in img.file.name):
                     # TODO check an object image for a good FWHM (last
-                    #  input)
+                    # input)
                     self.ap_data['oTime'].append(img.isot)
                     self.ap_data['oOffset'].append(
                         img.compute_offset((30, 35), 1090, 40, 2))
@@ -272,22 +271,29 @@ class Logging:
                         self.ap_data['cTime'].pop(i)
                         self.ap_data['cTime'].insert(i, img.isot)
                 detectors = []
+                arch_dir = Path('/data/apogee/archive/{}/'.format(
+                    self.args.sjd))
                 red_dir = Path('/data/apogee/quickred/{}/'.format(
                     self.args.sjd))
-                red_fil = red_dir / 'ap1D-a-{}.fits.fz'.format(img.exp_id)
-                # TODO Have this include tiers depending on 1D or 2D quickred
-                if red_fil.exists():
+                red_name = 'apR-a-{}.apz'.format(img.exp_id)
+                if (arch_dir / red_name).exists():
                     detectors.append('a')
+                # elif (red_dir / red_name.replace('1D', '2D')).exists():
+                    # detectors.append('2')
                 else:
                     detectors.append('x')
-                if (red_fil.parent / red_fil.name.replace(
-                        '-a-', '-b-')).exists():
+                if (arch_dir / red_name.replace('-a-', '-b-')).exists():
                     detectors.append('b')
+                # elif (red_dir / red_name.replace('-a-', '-b-').replace(
+                        # '1D', '2D')).exists():
+                    # detectors.append('2')
                 else:
                     detectors.append('x')
-                if (red_fil.parent / red_fil.name.replace(
-                        '-a-', '-c-')).exists():
+                if (arch_dir / red_name.replace('-a-', '-c-')).exists():
                     detectors.append('c')
+                # elif (red_dir / red_name.replace('-a-', '-c-').replace(
+                        # '1D', '2D')).exists():
+                    # detectors.append('2')
                 else:
                     detectors.append('x')
                 self.ap_data['iTime'].append(img.isot)
@@ -300,8 +306,8 @@ class Logging:
                 self.ap_data['iCart'].append(img.cart_id)
                 self.ap_data['iPlate'].append(img.plate_id)
         if self.args.boss:
-            print('Reading BOSS Data')
-            for image in tqdm(self.m_images):
+            print('Reading BOSS Data ({})'.format(len(self.b_images)))
+            for image in tqdm(self.b_images):
                 img = boss_data.BOSSRaw(image)
                 if img.cart_id not in self.data['cCart']:
                     self.data['cCart'].append(img.cart_id)
@@ -642,9 +648,9 @@ class Logging:
                 ap_cart = np.where(cart == self.ap_data['cCart'])[0][0]
 
                 print('# APOGEE')
-                print('{:<5} {:<8} {:<8} {:<12} {:<4} {:<6} {:<9}'
+                print('{:<5} {:<8} {:<8} {:<12} {:<4} {:<6} {:<5}'
                       ' {:<4}'.format('MJD', 'UTC', 'Exposure', 'Type',
-                                      'Dith', 'nReads', 'Pipeline',
+                                      'Dith', 'Reads', 'Arch',
                                       'Seeing'))
                 print('-' * 80)
                 window = self.get_window(self.ap_data, ap_cart)
@@ -659,7 +665,7 @@ class Logging:
                     self.ap_data['iDetector'][window],
                     self.ap_data['iSeeing'][window]
                 ):
-                    print('{:<5.0f} {:0>8} {:<8.0f} {:<12} {:<4} {:>6} {:<9}'
+                    print('{:<5.0f} {:0>8} {:<8.0f} {:<12} {:<4} {:>5} {:<5}'
                           ' {:>4.1f}'.format(int(mjd), iso[11:19], exp_id,
                                              exp_type,
                                              dith, nread, detectors, see))
@@ -751,9 +757,9 @@ class Logging:
         print('=' * 80)
         print('{:^80}'.format('APOGEE Data Summary'))
         print('=' * 80 + '\n')
-        print('{:<5} {:<8} {:<8} {:<8} {:<12} {:<4} {:<6} {:<8}'
+        print('{:<5} {:<8} {:<8} {:<8} {:<12} {:<4} {:<5} {:<5}'
               ' {:<6}'.format('MJD', 'UTC', 'Cart', 'Exposure', 'Type',
-                              'Dith', 'nReads', 'Pipeline',
+                              'Dith', 'Reads', 'Arch',
                               'Seeing'))
         print('-' * 80)
         if self.args.morning:
@@ -771,8 +777,8 @@ class Logging:
                 self.ap_data['iSeeing'][self.morning_filter]
             ):
                 print('{:<5.0f} {:>8} {:>2.0f}-{:<5.0f} {:<8.0f} {:<12} {:<4}'
-                      ' {:>6}'
-                      ' {:<8}'
+                      ' {:>5}'
+                      ' {:<5}'
                       ' {:>6.1f}'.format(int(mjd), iso[11:19], cart, plate,
                                          exp_id, exp_type,
                                          dith, nread, detectors, see))
@@ -809,16 +815,19 @@ class Logging:
             ['{:.3f}'.format(f) for f in np.diff(
                 self.ap_data['aOffset'][self.ap_data['aLamp'] == 'UNe'])])
         print('\n'.join(wrapper.wrap(une_str)))
-        obj_offsets = []
-        prev_dither = None
-        prev_f = 0.
-        for d, f in zip(self.ap_data['oDither'], self.ap_data['oOffset']):
-            if d != prev_dither:
-                obj_offsets.append('{:.3f}'.format(f - prev_f))
-            prev_dither = d
-            prev_f = f
-        obj_str = 'Object Offsets: {}'.format(obj_offsets)
+        obj_str = 'Object Offsets: {}'.format(
+            ['{:>6.3f}'.format(f) for f in np.diff(
+                self.ap_data['oOffset'])])
         print('\n'.join(wrapper.wrap(obj_str)))
+        # obj_offsets = []
+        # prev_dither = None
+        # prev_f = 0.
+        # for d, f in zip(self.ap_data['oDither'], self.ap_data['oOffset']):
+        #     if d != prev_dither:
+        #         obj_offsets.append('{:.3f}'.format(f - prev_f))
+        #     prev_dither = d
+        #     prev_f = f
+        # obj_str = 'Object Offsets: {}'.format(obj_offsets)
         print('\n')
 
     def log_support(self):
@@ -927,7 +936,7 @@ def main():
         args.apogee = True
         p_boss = True
         p_apogee = True
-        args.log_support = True
+        # args.log_support = True  # Because this usually produces wrong results
         args.mirrors = True
         args.telstatus = True
 
